export OS_USERNAME="<YOUR_USERNAME>"
export OS_PASSWORD="<YOUR_PASSWORD"
export OS_PROJECT_ID="<YOUR_PROJECT_ID>"

export OS_AUTH_URL='https://chi.uc.chameleoncloud.org:5000/v3'
export OS_IDENTITY_API_VERSION=3
export OS_INTERFACE=public
export OS_PROTOCOL=openid
export OS_AUTH_TYPE=v3oidcpassword
export OS_IDENTITY_PROVIDER=chameleon
export OS_DISCOVERY_ENDPOINT="https://auth.chameleoncloud.org/auth/realms/chameleon/.well-known/openid-configuration"
export OS_CLIENT_ID=keystone-uc-prod
export OS_ACCESS_TOKEN_TYPE=access_token
export OS_CLIENT_SECRET=none
export OS_REGION_NAME=CHI@UC
